@@ -17,13 +17,6 @@ typedef struct {
 	XpmAttributes	attributes;
 } XpmIcon;
 
-/* Global variable */
-Display	*display;
-Window          Root;
-GC              NormalGC;
-XpmIcon         wmgen;
-XpmIcon         text_pixmap;
-XFontSet        fontset;
 
 /* Function Prototypes */
 void AddMouseRegion(int index, int left, int top, int right, int bottom);
@@ -45,5 +38,4 @@ void drawnString(int dest_x, int dest_y, const char *string,
 void GetXPM(XpmIcon *wmgen, char *pixmap_bytes[]);
 void drawImageString(int dest_x, int dest_y, const char *string);
 
-
 #endif
